## Variation onnxruntime_gpu

### Windows

* General installation notes: https://onnxruntime.ai/docs/install
* Notes about dependencies: [link](https://onnxruntime.ai/docs/execution-providers/CUDA-ExecutionProvider.html).
